Change in osmo-pcu[master]: bts: Rename mslot_class_from_ra

This is merely a historical archive of years 2008-2021, before the migration to mailman3.

A maintained and still updated list archive can be found at https://lists.osmocom.org/hyperkitty/list/gerrit-log@lists.osmocom.org/.

pespin gerrit-no-reply at lists.osmocom.org
Fri May 8 12:22:20 UTC 2020


pespin has uploaded this change for review. ( https://gerrit.osmocom.org/c/osmo-pcu/+/18129 )


Change subject: bts: Rename mslot_class_from_ra
......................................................................

bts: Rename mslot_class_from_ra

Ther function is actually returning an EGPRS multislot class, os let's
update naming. The variable using the return value was already being
passed as egprs_ms_class to tbf_alloc_ul_tbf().

Change-Id: Idb51836c8c9dd4e865bf2cb0b0c24155662f2ae8
---
M src/bts.cpp
1 file changed, 5 insertions(+), 5 deletions(-)



  git pull ssh://gerrit.osmocom.org:29418/osmo-pcu refs/changes/29/18129/1

diff --git a/src/bts.cpp b/src/bts.cpp
index 5e1725c..be0c61e 100644
--- a/src/bts.cpp
+++ b/src/bts.cpp
@@ -664,12 +664,13 @@
 	return fn;
 }
 
-static inline uint16_t mslot_class_from_ra(uint16_t ra, bool is_11bit)
+/* 3GPP TS 44.060 Table 11.2.5a.3: EGPRS PACKET CHANNEL REQUEST  */
+static inline uint16_t egprs_mslot_class_from_ra(uint16_t ra, bool is_11bit)
 {
 	if (is_11bit)
 		return (ra & 0x3e0) >> 5;
 
 	/* set multislot class to 0 for 8-bit RACH, since we don't know it yet */
 	return 0;
 }
 
@@ -741,7 +742,7 @@
 	int plen;
 	uint8_t usf = 7;
 	uint8_t tsc = 0, ta = qta2ta(qta);
-	uint16_t ms_class = mslot_class_from_ra(ra, is_11bit);
+	uint16_t egprs_ms_class = egprs_mslot_class_from_ra(ra, is_11bit);
 	bool failure = false;
 
 	rach_frame();
@@ -784,8 +785,7 @@
 	} else {
 		// Create new TBF
 		/* FIXME: Copy and paste with other routines.. */
-
-		tbf = tbf_alloc_ul_tbf(&m_bts, NULL, -1, 0, ms_class, true);
+		tbf = tbf_alloc_ul_tbf(&m_bts, NULL, -1, 0, egprs_ms_class, true);
 
 		if (!tbf) {
 			LOGP(DRLCMAC, LOGL_NOTICE, "No PDCH resource sending "
@@ -664,12 +664,13 @@
 		return (ra & 0x3e0) >> 5;
 
-	/* set multislot class to 0 for 8-bit RACH, since we don't know it yet */
+	/* set EGPRS multislot class to 0 for 8-bit RACH, since we don't know it yet */
 	return 0;
 }

-- 
To view, visit https://gerrit.osmocom.org/c/osmo-pcu/+/18129
To unsubscribe, or for help writing mail filters, visit https://gerrit.osmocom.org/settings

Gerrit-Project: osmo-pcu
Gerrit-Branch: master
Gerrit-Change-Id: Idb51836c8c9dd4e865bf2cb0b0c24155662f2ae8
Gerrit-Change-Number: 18129
Gerrit-PatchSet: 1
Gerrit-Owner: pespin <pespin at sysmocom.de>
Gerrit-MessageType: newchange
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.osmocom.org/pipermail/gerrit-log/attachments/20200508/3e7f2b9b/attachment.htm>


More information about the gerrit-log mailing list